# readin_ucinet
Read in UCINET text files as pandas DataFrame

**Prerequisites:** Requires pandas installation <br/>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; https://pandas.pydata.org/pandas-docs/stable/getting_started/install.html?highlight=install

**Example Usage:** <br/>
&nbsp;&nbsp;&nbsp;&nbsp; &nbsp;&nbsp;&nbsp;&nbsp; Enter path of dataset: C://User//Documents//Datasets//UCINET// <br/>
&nbsp;&nbsp;&nbsp;&nbsp; &nbsp;&nbsp;&nbsp;&nbsp; Enter name of file: myfile.dat

**Returns: pandas DataFrame or TextParser <br/>**
&nbsp;&nbsp;&nbsp;&nbsp; &nbsp;&nbsp;&nbsp;&nbsp; A comma-separated values (csv) file is returned as two-dimensional data structure with labeled axes.


Make sure not to wrap your command path arguments in string literals
